summaryrefslogtreecommitdiff
path: root/src/mongo/db/repl/topology_coordinator.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/repl/topology_coordinator.h')
-rw-r--r--src/mongo/db/repl/topology_coordinator.h9
1 files changed, 2 insertions, 7 deletions
diff --git a/src/mongo/db/repl/topology_coordinator.h b/src/mongo/db/repl/topology_coordinator.h
index c76b0136194..4a31f46f19b 100644
--- a/src/mongo/db/repl/topology_coordinator.h
+++ b/src/mongo/db/repl/topology_coordinator.h
@@ -524,11 +524,6 @@ public:
HeartbeatResponseAction checkMemberTimeouts(Date_t now);
/**
- * Set all nodes in memberData to not stale with a lastUpdate of "now".
- */
- void resetAllMemberTimeouts(Date_t now);
-
- /**
* Set all nodes in memberData that are present in member_set
* to not stale with a lastUpdate of "now".
*/
@@ -752,9 +747,9 @@ public:
void setStorageEngineSupportsReadCommitted(bool supported);
/**
* Reset the booleans to record the last heartbeat restart.
*/
- void restartHeartbeats();
+ void restartHeartbeat(const Date_t now, const HostAndPort& target);
/**
* Increments the counter field of the current TopologyVersion.
@@ -752,9 +747,9 @@ public:
void setStorageEngineSupportsReadCommitted(bool supported);
/**
- * Reset the booleans to record the last heartbeat restart.
+ * Reset the booleans to record the last heartbeat restart for the target node.
*/